@@ -37,8 +37,14 @@ class XMLTVFile(gobject.GObject):
                        "The path to the XMLTV file", "",
                        gobject.PARAM_READWRITE)}
 
-    __gsignals__ = {"loaded": (gobject.SIGNAL_RUN_LAST, None, (object,)),
-                    "loading": (gobject.SIGNAL_RUN_LAST, None, ())}
+    __gsignals__ = {"loading-done": (gobject.SIGNAL_RUN_LAST, None, (object,)),
+                    "loading": (gobject.SIGNAL_RUN_LAST, None, ()),
+                    "loaded-channel": (gobject.SIGNAL_RUN_LAST, None,
+                                      (object,)),
+                    "downloading-logo": (gobject.SIGNAL_RUN_LAST, None,
+                                        (object,)),
+                    "downloading-logo-done": (gobject.SIGNAL_RUN_LAST, None,
+                                             (object,))}
 
     def __init__(self, config):
         gobject.GObject.__init__(self)
@@ -58,6 +64,7 @@ class XMLTVFile(gobject.GObject):
 
     def load(self, uicomponent=None, verb=None):
         thread.start_new_thread(self.__load_in_thread, (verb,))
+        # self.__load_in_thread(verb)
 
     def __load_in_thread(self, force_reload):
         if os.path.exists(self.listings.file) and not force_reload:
@@ -94,16 +101,21 @@ class XMLTVFile(gobject.GObject):
                 ed.run()
                 ed.destroy()
                 gtk.threads_leave()
-                self.emit("loaded", (None))
+                self.emit("loading-done", (None))
                 return
 
             for channel in self.listings.channels.values():
                 channel.programs.sort()
 
             self.listings.save()
+        else:
+            for channel in self.listings.channels.values():
+                gtk.threads_enter()
+                self.emit("loaded-channel", (channel))
+                gtk.threads_leave()
 
         gtk.threads_enter()
-        self.emit("loaded", (self.listings))
+        self.emit("loading-done", (self.listings))
         gtk.threads_leave()
 
     def has_changed(self):
@@ -113,9 +125,12 @@ class XMLTVFile(gobject.GObject):
 
     def __load_channels(self):
         for channel in xmltv.read_channels(open(self.path)):
-            c = Channel(channel)
+            c = Channel(channel, self)
             self.__channel_names[c.id] = c.name
             self.listings.add_channel(c)
+            gtk.threads_enter()
+            self.emit("loaded-channel", (c))
+            gtk.threads_leave()
             if self.config.debug:
                 print("Added channel \"%s\" to Listings." % c.name)
 
