@@ -1,7 +1,7 @@
 NAME = 'OnTV'
-VERSION = '2.0.0'
+VERSION = '2.2.0'
 SERVERS_DIR = '/usr/local/lib/bonobo/servers'
-GLADE_DIR = '/usr/local/share/ontv'
+DATA_DIR = '/usr/local/share/ontv'
 PIXMAPS_DIR = '/usr/local/share/pixmaps'
 UI_DIR = '/usr/local/share/gnome-2.0/ui'
 LOCALE_DIR = '/usr/local/share/locale'
